# fluffycow

[![Build Status](https://travis-ci.org/ChrisTimperley/fluffycow.svg?branch=master)](https://travis-ci.org/ChrisTimperley/fluffycow)
[![PyPI version](https://badge.fury.io/py/fluffycow.svg)](https://badge.fury.io/py/fluffycow)
[![Python versions](https://img.shields.io/pypi/pyversions/fluffycow.svg)](https://pypi.org/project/fluffycow)

A blackbox fuzzing toolkit for containerised ROS apps

![fluffycow](https://static.boredpanda.com/blog/wp-content/uploads/2014/03/cute-fluffy-animals-33.jpg)

(image credit: [Matt Lautner](http://www.lautnerfarms.com/sires/texas-tornado/).)
